============
Installation
============

This package extends and depends on the `Gurobi <https://www.gurobi.com/>`_ python package. Thus, you will need it installed locally before you can use this package.

At the command line::

    pip install moiptimiser
